import React from 'react'
import PropTypes from 'prop-types'
import { useEffect } from 'react'
import { simplify } from '../utils/children'

/**
 * Benchmark a component's render speed.
 * 
 * @param  {object}   props.children  - An instance of the component to test
 * @param  {function} props.onMeasure - Called with the render speed and `children`
 * @return {object}                   - Whatever is given as `children`
 */
const Benchmark = ({
    children = null,
    onMeasure
}) => {
    const start = performance.now()

    useEffect(() => {
        const end = performance.now()
        onMeasure(end - start, children)
    })

    return children
}

Benchmark.propTypes = {
    children: PropTypes.node,
    onMeasure: PropTypes.func.isRequired
}

export default React.memo(Benchmark, (prev, next) => (
    JSON.stringify(simplify(prev.children)) ===
    JSON.stringify(simplify(next.children))
))