import React, { useRef, useContext } from 'react'
import PropTypes from 'prop-types'
import { useHoverDirty } from 'react-use'
import Action from './action.jsx'
import { ThemeContext } from '../utils'

/**
 * A styled button (wraps the base `Action` component).
 * 
 * @param  {object} props.style    - Override or add any additional styles
 * @param  {object} props.children - Any valid react children
 * @return {object}                - React markup
 */
const Button = ({
    style = {},
    children
}) => {
    const ref = useRef(null)
    const hovering = useHoverDirty(ref)
    const { neutral, primary } = useContext(ThemeContext)

    return (
        <Action
            ref={ref}
            element="button"
            style={{
                ...style,
                cursor: 'pointer',
                color: hovering ? neutral[0] : 'inherit',
                background: hovering ? primary[Math.ceil(primary.length / 2)] : neutral[0]
            }}
        >
            { children }
        </Action>
    )
}

Button.propTypes = {
    style: PropTypes.object,
    children: PropTypes.node
}

export default Button