import React, { forwardRef, useState, useContext } from 'react'
import PropTypes from 'prop-types'
import { presets, ThemeContext } from '../utils'

/**
 * Display some content within an animated card. See the available sub-
 * components for internal layout options.
 * 
 * @param  {number} props.width      - Width of the card
 * @param  {number} props.height     - Height of the card
 * @param  {object} props.style      - Override or add any additional styles
 * @param  {object} props.children   - Any valid react children
 * @return {object}                  - React markup
 */
const Card = forwardRef(({
    width = presets.medium.width,
    height = presets.medium.height,
    hidden = false,
    style,
    children
}, ref) => {
    const {neutral} = useContext(ThemeContext)
    
    return (
        <article
            ref={ref}
            style={{
                width,
                height,
                display: 'flex',
                flexDirection: 'column',
                borderRadius: 10,
                background: neutral[0],
                boxShadow: `0 0 25px ${neutral[2]}`,
                boxSizing: 'border-box',
                overflow: 'hidden',
                ...style
            }}
        >
            { !hidden ? children : null }
        </article>
    )
})

Card.propTypes = {
    width: PropTypes.number,
    height: PropTypes.number,
    hidden: PropTypes.bool,
    style: PropTypes.object,
    children: PropTypes.node
}

export default Card