import React, { useState, useRef } from 'react'
import PropTypes from 'prop-types'
import Base from './base.jsx'
import Benchmark from './benchmark.jsx'
import Fields from './fields.jsx'
import Field from './field.jsx'

/**
 * An isolated testing ground for components. Render your component as a child
 * to get diagnostics and optimization tips.
 * 
 * @param  {object} props.children - A single react node
 * @return {object}                - React markup
 */
const Lab = ({
    children
}) => {
    const container = useRef(null)
    const [speed, setSpeed] = useState(null)
    const [elements, setElements] = useState(null)

    return (
        <Base>
            <main
                style={{
                    display: 'flex',
                    minHeight: '100vh',
                    alignItems: 'center',
                    justifyContent: 'center'
                }}
            >
                <div
                    ref={ container }
                    style={{
                        display: 'flex',
                        flexWrap: 'wrap',
                        maxWidth: 720
                    }}
                >
                    <Benchmark onMeasure={time => {
                        const nodes = container.current.querySelectorAll('*')
                        const children = Array.from(nodes)
                        const index = children.findIndex(el => el.id === 'benchmark')
                        const measured = children.slice(0, index)
                        
                        setSpeed(Math.floor(time))
                        setElements(measured.length)
                    }}>
                        { children }
                    </Benchmark>
                    <aside
                        id="benchmark"
                        style={{
                            marginLeft: 24
                        }}
                    >
                        <h1
                            style={{
                                fontSize: 25
                            }}
                        >
                            Diagnostics
                        </h1>
                        <Fields>
                            <Field label="Speed">
                                ~{speed}ms
                            </Field>
                            <Field label="Elements">
                                {elements}
                            </Field>
                        </Fields>
                    </aside>
                </div>
            </main>
        </Base>
    )
}

Lab.propTypes = {
    children: PropTypes.node
}

export default Lab