import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils'

/**
 * Display a subtitle, typically paired with a `<Title />`.
 * 
 * @param  {object} props.style    - Override or add any additional styles
 * @param  {object} props.children - Any valid react children
 * @return {object}                - React markup
 */
const Subtitle = ({
    style,
    children
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <h3
            style={{
                marginTop: 6,
                fontSize: 12.8,
                fontWeight: 600,
                letterSpacing: 0.25,
                color: neutral[neutral.length - 2],
                ...style
            }}
        >
            {children}
        </h3>
    )
}

Subtitle.propTypes = {
    style: PropTypes.object,
    children: PropTypes.node
}

export default Subtitle