import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils'

/**
 * Display a full width section and title. Typically, a few of these are used
 * to display high-level summaries of the data within a product.
 * 
 * @param  {string}  props.title     - Title of the summary
 * @param  {boolean} props.alternate - Changes the background color
 * @param  {number}  props.margin    - Left gutter for title
 * @param  {object}  props.children  - Any valid react children
 * @return {object}                  - React markup
 */
const Summary = ({
    title = 'Untitled',
    alternate = false,
    margin = 24,
    children
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <div
            style={{
                height: 720,
                padding: '56px 0',
                boxSizing: 'border-box',
                background: alternate ? neutral[0] : neutral[1]
            }}
        >
            <h2
                style={{
                    fontSize: 39,
                    fontWeight: 700,
                    paddingLeft: margin,
                    paddingBottom: 12,
                    borderBottom: `4px solid ${alternate ? neutral[1] : neutral[0]}`,
                    color: neutral[neutral.length - 1]
                }}
            >
                { title }
            </h2>
            { children }
        </div>
    )
}

Summary.propTypes = {
    title: PropTypes.node,
    alternate: PropTypes.bool,
    children: PropTypes.node
}

export default Summary