import { createContext } from 'react'

/**
 * Preset dimensions for cards.
 * 
 * @type {object}
 */
export const presets = {
    small: { width: 243, height: 160 },
    medium: { width: 243, height: 360 },
    large: { width: 420, height: 260 }
}

/**
 * Context instance for color scheming. The format is just an initial concept,
 * based on a modified version of one of the naming ideas in the article below.
 * 
 * @see https://css-tricks.com/what-do-you-name-color-variables/
 * @type {object}
 */
export const ThemeContext = createContext({
    neutral: [],
    primary: [],
    secondary: []
})

/**
 * Default resizing algorithm
 * 
 * @param  {object} dimensions - ...
 * @return {object}            - ...
 */
export const resizeGridDefault = dimensions => {
    let gap = 16
    let cardWidth = presets.medium.width
    let cardHeight = presets.medium.height
    let availableColumns = Math.floor(dimensions.width / (cardWidth + 1.6 * gap))

    if (availableColumns < 2) {
        cardWidth = dimensions.width - (3 * gap)
        cardHeight = cardWidth / 1.618
    }

    return {
        columns: Math.min(availableColumns, 4),
        cardWidth,
        cardHeight
    }
}